@file:OptIn(ExperimentalCoroutinesApi::class)

package dev.adriankuta.pixabay.feature.details

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import dev.adriankuta.pixabay.data.repository.ImageRepository
import kotlinx.coroutines.ExperimentalCoroutinesApi
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.SharingStarted
import kotlinx.coroutines.flow.filterNotNull
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.flow.stateIn
import javax.inject.Inject

@HiltViewModel
class PhotoDetailViewModel @Inject constructor(
    private val imageRepository: ImageRepository
) : ViewModel() {

    private val _idToLoad = MutableStateFlow<Int?>(null)

    private val loadedData = _idToLoad
        .filterNotNull()
        .map { id ->
            imageRepository.searchImageById(id)
        }

    val uiState = loadedData
        .map { PhotoDetailUiState.Success(it) }
        .stateIn(
            scope = viewModelScope,
            started = SharingStarted.WhileSubscribed(stopTimeoutMillis = 5000),
            initialValue = PhotoDetailUiState.Loading
        )


    fun loadImage(id: Int) {
        _idToLoad.value = id
    }
}